@@ -1,6 +1,6 @@
 package Object::Simple;
 
-our $VERSION = '3.17';
+our $VERSION = '3.1701';
 
 use strict;
 use warnings;
@@ -167,21 +167,21 @@ sub dual_attr {
 
 =head1 NAME
 
-Object::Simple - Simplest class builder, Mojo::Base porting
+Object::Simple - Simplest class builder, Mojo::Base porting, fast and less memory
 
 =over
 
-=item 1.
+=item *
 
-B<Simplest class builder>. All you learn is only C<has> function.
+B<Simplest class builder>. All you learn is only C<has> function!
 
-=item 2.
+=item *
 
 B<Mojo::Base porting>. Do you like L<Mojolicious>? If so, this is good choices!
 
-=item 3.
+=item *
 
-B<Fast and less memory>. Fast C<new> method, Fast accessor method.
+B<Fast and less memory>. Fast C<new> and accessor method. Memory saving implementation.
 
 =back
 
@@ -233,37 +233,36 @@ Inheritance
 
 =head1 DESCRIPTION
 
-B<Simplest class builder>: All you learn is only C<has> function.
-You can learn all features of L<Object::Simple> in one hour 
+Object::Simple is B<Simplest> class builder. All you learn is only C<has> function.
+You can learn all features of L<Object::Simple> in B<an hour>. There is nothing difficult.
 
-B<Mojo::Base porting>: Do you like L<Mojolicious>? If so, this is good choices!
-If you have known L<Mojo::Base>, you don't learn anything.
+Do you like L<Mojolicious>? In fact, Object::Simple is L<Mojo::Base> porting. Mojo::Base is basic class builder in Mojolicious project.
+If you like Mojolicious, this is good choice. If you have known Mojo::Base, you learn nothing.
 
-B<Fast and less memory>: Fast C<new> method, Fast accessor method.
-In pure perl implementation, this module is much fast.
+C<new> and accessor method is fast. Implementaion is pure perl and save instructions as possible.
+Memory is saved. Extra objects is not created at all. Very light-weight object-oriented module.
 
-B<Object::Simple vs Class::Accessor::Fast>
+Comparison with L<Class::Accessor::Fast>
 
-L<Class::Accessor::Fast> is simple, but lack offten used features.
+Class::Accessor::Fast is simple, but lack often used features.
 C<new> method can't receive hash arguments.
 Default value can't be specified.
-If multipule values is set through the accessor,
+If multiple values is set through the accessor,
 its value is converted to array reference without warnings.
 
-B<Object::Simple vs Moose>
+Comparison with L<Moose>
 
-Some people find L<Moose> too complex, and dislike it because
-it depends on much many modules. Some one say that L<Moose> is 
-almost like another language and does not fit the familiar 
-perl syntax. In some cases, in particular smaller projects, 
-some people feel that L<Moose> will increase complexity
-and therefore decrease programmer efficiency.
-In addition, L<Moose> can be slow at compile-time and 
-its memory usage can get large.
+Moose has very complex syntax and depend on much many modules.
+You have to learn many things to do object-oriented programing.
+Understanding source code is difficult.
+Compile-time is very slow and memory usage is very large.
+Execution speed is not fast.
+For simple OO, Moose is overkill.
+L<Moo> is improved in this point.
 
 =head1 TUTORIAL
 
-=head2 1. Define class and create accessor
+=head2 1. Create class and accessor
 
 At first, you create class.
 
@@ -348,7 +347,7 @@ You can pass array to C<new> method.
 
   my $point = Point->new(4, 5);
 
-=head2 3. Class example
+=head2 3. Examples - class, accessor, inheritance and method overriding
 
 I introduce L<Object::Simple> example.
 
@@ -378,7 +377,7 @@ Use Point class.
 
 Point3D class: Point3D inherit Point class.
 Point3D class has C<z> accessor in addition to C<x> and C<y>.
-C<clear> method is overriden to clear C<x>, C<y> and C<z>.
+C<clear> method is overridden to clear C<x>, C<y> and C<z>.
 
   package Point3D;
   use Point -base;
@@ -401,7 +400,7 @@ Use Point3D class.
   $point->z(9);
   $point->clear;
 
-=head2 4. Easy description of Object-Oriented programing
+=head2 4. What is Object-Oriented programing?
 
 I introduce concepts of Object-Oriented programing.
 
@@ -464,7 +463,7 @@ Encapsulation means that
 you don't touch internal data directory.
 You must use public method when you access internal data.
 
-Create accessor and use it to keep thie rule.
+Create accessor and use it to keep this rule.
 
   my $value = $obj->foo;
   $obj->foo(1);
@@ -475,7 +474,7 @@ Third concept is polymorphism.
 Polymorphism is divided into two concepts,
 overload and override
 
-Perl programer don't need to care overload.
+Perl programmer don't need to care overload.
 Perl is dynamic type language.
 Subroutine can receive any value.
 
@@ -535,7 +534,7 @@ Create accessor.
 Create accessor. C<has> receive
 accessor name and default value.
 Default value is optional.
-If you want to create multipule accessors at once,
+If you want to create multiple accessors at once,
 specify accessor names as array reference at first argument.
 
 If you want to specify reference or object as default value,
@@ -609,6 +608,32 @@ You can also use the following syntax.
   package Bar;
   use Object::Simple -base => 'Foo';
 
+=head1 FAQ
+
+=head2 Why do you receive personal attack in cpanratings?
+
+  I don't always oppose reinventing the wheel, in the case of this module, however, I wonder if it is worthy to be registered at any cost on CPAN.
+ 
+  You already have Moose, Mouse, etc. and otherwise Class::Accessor if you dislike the previous modules. Enough already! Do you need yet another but half-baked module, nonetheless?
+
+  I hear the author says that he is going to enlighten the perl's newbie, to be honest, however, in no case is he qualified to do so. In fact, he seems to be conceited because of the publication of his only book regarding Perl.
+
+  In any case, I fear that what he says and does would mislead the newbie (especially Japanese) deceived by another handle name of his, "perlcodesample".
+
+Taro Nishino is Moose believer. I wrote criticism about Moose in past in my perl blog. He was very angry and do personal attack to me with very dirty words.
+
+=head2 Really enough object-oriented programing with this few features?
+
+Yes, for example, Mojolicious is very big project, but in fact, source code is clean only using single inheritance.
+Generally speaking, readable source code is build by simple concepts, not complex features.
+
+=head2 Object::Simple is fastest module?
+
+No, Object::Simple is not fastest module, but enough fast. If you really need performance, you can access hash value directory.
+
+  # I want performance in some places. Let's access hash value directory!
+  $self->{x};
+
 =head1 BACKWARDS COMPATIBILITY POLICY
 
 If a functionality is DEPRECATED, you can know it by DEPRECATED warnings.
@@ -642,22 +667,26 @@ by mail or github L<http://github.com/yuki-kimoto/Object-Simple>
 
 Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
 
+I'm pleasure if you send message for cheer. I can get power by only your messages!
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2016 Yuki Kimoto, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Artistic v2(This is same as L<Mojolicious> licence).
+under the same terms as Artistic v2.
 
-=head1 Object::Simple used projects
+This is same as L<Mojolicious> licence.
 
-L<Object::Simple> is used in the following projects.
+=head1 USERS
+
+Projects using L<Object::Simple>.
 
 =over 4
 
 =item *
 
-GitPrep - Portable GitHub system into your own server L<https://github.com/yuki-kimoto/gitprep>
+GitPrep - Portable GitHub system into your own server. L<https://github.com/yuki-kimoto/gitprep>
 
 =item *
 
@@ -676,4 +705,3 @@ L<Mojo::Base>, L<Class::Accessor>, L<Class::Accessor::Fast>, L<Moose>, L<Moo>.
 =cut
 
 1;
-
